@@ -170,13 +170,13 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
         if (mime.isEmpty ()) {
             for (Node *p = mrl->parentNode (); p; p = p->parentNode ()) {
                 Mrl *m = p->mrl ();
-                if (m && m->linkNode ()->audio_only) {
-                    mrl->linkNode ()->audio_only = true;
+                if (m && m->audio_only) {
+                    mrl->audio_only = true;
                     break;
                 }
             }
         } else {
-            mrl->linkNode ()->audio_only |= isAudioOnlyMime (mime);
+            mrl->audio_only |= isAudioOnlyMime (mime);
         }
     }
     debugLog () << "Actor::wget " << str << endl;
@@ -228,8 +228,6 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
         line = textstream.readLine ();
     } while (!line.isNull () && line.stripWhiteSpace ().isEmpty ());
     if (!line.isNull ()) {
-        if (cur_elm->isPlayable ())
-            cur_elm = cur_elm->mrl ()->linkNode ();
         bool pls_groupfound =
             line.startsWith ("[") && line.endsWith ("]") &&
             line.mid (1, line.length () - 2).stripWhiteSpace () == "playlist";
@@ -458,8 +456,7 @@ KDE_NO_EXPORT void MediaInfo::redirected (IOJob *, const String &url) {
 //------------------------%<----------------------------------------------------
 
 AudioVideoActor::AudioVideoActor (ActorAgent *manager, Node *node)
- : Actor (manager, node),
-   ignore_pause (false) {
+ : Actor (manager, node) {
 }
 
 AudioVideoActor::~AudioVideoActor () {
@@ -474,9 +471,7 @@ bool AudioVideoActor::play () {
     } else if (m_agent->control ()->requestPlayURL (mrl ())) {
         if (!mrl ()->audio_only)
             m_agent->control ()->viewArea ()->setAudioVideoNode (m_node);
-        ignore_pause = true;
         m_node->defer ();
-        ignore_pause = false;
         return true;
     }
     return false;
@@ -491,13 +486,13 @@ void AudioVideoActor::stop () {
 
 void AudioVideoActor::pause () {
     Process *process = m_agent->control ()->process ();
-    if (!ignore_pause && process)
+    if (process && process->state () == Process::Playing)
         process->pause ();
 }
 
 void AudioVideoActor::unpause () {
     Process *process = m_agent->control ()->process ();
-    if (!ignore_pause && process)
+    if (process && process->state () == Process::Paused)
         process->pause ();
 }
 
@@ -692,7 +687,10 @@ KDE_NO_EXPORT void ImageActor::sizes (SSize &size) {
 }
 
 gboolean movieUpdateTimeout (void * p) {
-   return ((ImageActor *)p)->movieTimer ();
+#ifdef DEBUG_TIMERS
+    debugLog() << "movieUpdateTimeout" << endl;
+#endif
+    return ((ImageActor *)p)->movieTimer ();
 }
 
 bool ImageActor::movieTimer () {
