@@ -298,6 +298,7 @@ static void create_toolbar (Application * app) {
     /* Create needed variables */
     GtkToolItem *tb_open;
     GtkToolItem *tb_separator;
+    GtkWidget *vbox;
 
     /* Create toolbar */
     app->main_toolbar = gtk_toolbar_new();
@@ -332,7 +333,9 @@ static void create_toolbar (Application * app) {
     gtk_tool_item_set_expand (app->tb_location, TRUE);
     gtk_tool_item_set_expand (app->tb_progress, TRUE);
     /* Add combobox inside toolitem */
-    gtk_container_add (GTK_CONTAINER (app->tb_location), app->location_bar);
+    vbox = gtk_vbox_new (false, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), app->location_bar, true, false, 0);
+    gtk_container_add (GTK_CONTAINER (app->tb_location), vbox);
     gtk_container_add (GTK_CONTAINER (app->tb_progress), app->progress_bar);
 
     /* Create separator */
