@@ -58,6 +58,7 @@ typedef struct _Application {
     GObject *program;
     GtkWindow *window;
     GtkWindow *window_fullscreen;
+    GtkWindow *window_downloads;
     osso_context_t *osso_context;
     GtkWidget * main_toolbar;
     GtkToolItem * tb_prev;
@@ -70,6 +71,7 @@ typedef struct _Application {
     GtkToolItem * tb_go;
     GtkToolItem * tb_progress;
     GtkWidget * playlist_view;
+    GtkWidget * downloads_view;
     GtkWidget * infopanel_view;
     GtkWidget * info_viewport;
     GtkWidget * html_infopanel_view;
@@ -103,6 +105,7 @@ GtkWidget * createTreeView (Application * app);
 void togglePlaylistShowAll (Application *app);
 void togglePlaylistEdit (Application *app);
 void playerMenuActivate (GtkMenuItem *item, Application *app);
+void showDownloadPage (GtkMenuItem *item, Application *app);
 gboolean cb_mainview_delete (GtkObject *w, GdkEvent *event, Application *app);
 gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app);
 void cb_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *arg2, Application * app);
