@@ -1568,6 +1568,7 @@ public:
         : FileDocument (id_node_download_document, "", ctrl)
     {
         readFromFile (ctrl->data_dir + "/downloads.xml");
+        resolved = true;
     }
 
     virtual Node *childFromTag (const String &tag)
@@ -1749,6 +1750,16 @@ downloadTapped (GtkTreeView *view, GtkTreePath *path, Application *app)
     }
 }
 
+static void addPlainDownload (GtkButton *, Application *app)
+{
+    String url = getUserInput (app, "Download URL",
+            "Please enter the link to download", "http://");
+    if (!url.isEmpty () && url != "http://") {
+        Control *ctrl = CONTROL(app);
+        ctrl->downloader->createDownload (url, String ());
+    }
+}
+
 void showDownloadPage (GtkMenuItem *, Application *app)
 {
     Control *ctrl = CONTROL(app);
@@ -1782,6 +1793,16 @@ void showDownloadPage (GtkMenuItem *, Application *app)
         gtk_container_add (GTK_CONTAINER (scroller), app->downloads_view);
         gtk_container_add (GTK_CONTAINER (win), scroller);
         gtk_widget_show_all (scroller);
+
+        HildonAppMenu *menu = HILDON_APP_MENU (hildon_app_menu_new ());
+        GtkWidget *item = hildon_gtk_button_new (HILDON_SIZE_AUTO);
+        gtk_button_set_label (GTK_BUTTON (item), "Add plain Download");
+        hildon_app_menu_append (menu, GTK_BUTTON (item));
+        g_signal_connect_after (G_OBJECT (item), "clicked",
+                G_CALLBACK (addPlainDownload), app);
+        gtk_widget_show_all (GTK_WIDGET (menu));
+        hildon_window_set_app_menu (HILDON_WINDOW (win), menu);
+
         app->window_downloads = GTK_WINDOW (win);
         hildon_program_add_window (HILDON_PROGRAM (app->program), win);
     }
