@@ -86,7 +86,7 @@ static GdkPixbuf *iconForNode (Node *n, int child_count) {
         return child_count > 0 ? auxiliary_fld_pix : auxiliary_pix;
     return n->isPlayable()
         ? n->mrl ()->resolved
-            ? n->mrl ()->linkNode ()->audio_only
+            ? n->mrl ()->audio_only
                 ? music_pix
                 : video_pix
             : video_link_pix
@@ -103,7 +103,7 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     GtkTreeIter iter, citer, cciter;
     bool m_have_dark_nodes = false;
     int child_count = 0;
-    if (!pld->show_all && !e->expose () && piter) {
+    if (!pld->show_all && !e->role (RolePlaylist) && piter) {
         if (pld->current.ptr () == e)
             *fpath = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), piter);
         for (Node *c = e->firstChild (); c; c = c->nextSibling ())
@@ -114,24 +114,13 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
         gtk_tree_store_append (tree_store, &iter, piter);
     else
         iter = *riter;
-    String text (e->caption ());
+    PlaylistRole *title = (PlaylistRole *) e->role (RolePlaylist);
+    String text (title ? title->caption () : "");
     if (text.isEmpty ()) {
         Mrl *mrl = e->mrl ();
         text = e->nodeName ();
-        if (mrl && !pld->show_all) {
-            if (!mrl->src.isEmpty())
-                text = mrl->src; // URL(mrl->src).url (); //prettyURL();
-            else if (e->isDocument ())
-                text = e->hasChildNodes () ? "unnamed" : "None";
-        } else if (e->id == id_node_text) {
-            String txt (e->nodeValue ());
-            int pos = txt.indexOf (Char ('\n'));
-            if (pos > -1) {
-                txt.truncate (pos);
-                txt += String (" ..");
-            }
-            text = txt;
-        }
+        if (!pld->show_all && e->isDocument ())
+            text = e->hasChildNodes () ? "unnamed" : "none";
     }
     gtk_tree_store_set (tree_store, &iter,
             COL_TEXT, (const char *) text, COL_ID, pld->id, -1);
@@ -179,16 +168,27 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     g_value_unset (&value);
 }*/
 
-static gboolean findNode (PlayListData *pld, GtkTreeModel *model, Node *node, GtkTreeIter *iter) {
+static gboolean findFirstExposed (Node *node, bool recursive)
+{
+    if (node->role (RolePlaylist))
+        return true;
+    if (recursive)
+        for (Node *c = node->firstChild (); c; c = c->nextSibling ())
+            if (findFirstExposed (c, true))
+                return true;
+    return false;
+}
+
+static gboolean findNodeImpl (PlayListData *pld, GtkTreeModel *model, Node *node, GtkTreeIter *iter, bool &expand) {
     Node *p = node->parentNode ();
     if (p) {
-        if (!findNode (pld, model, p, iter))
+        if (!findNodeImpl (pld, model, p, iter, expand))
             return false;
-        bool first_exposed = false;
         for (Node *n = p->firstChild (); n; n = n->nextSibling ()) {
-            if (pld->show_all || n->expose ()) {
-                if (!first_exposed) {
-                    first_exposed = true;
+            bool expose = pld->show_all || findFirstExposed (n, n != node);
+            if (expose) {
+                if (expand) {
+                    expand = false;
                     GtkTreeIter piter = *iter;
                     if (!gtk_tree_model_iter_children (model, iter, &piter))
                         return false;
@@ -200,16 +200,26 @@ static gboolean findNode (PlayListData *pld, GtkTreeModel *model, Node *node, Gt
                     return false;
                 }
             }
-            if (n == node)
+            if (n == node) {
+                if (expose)
+                    expand = true;
                 return true;
+            }
         }
         errorLog() << "findNode node not found" << endl;
         return false;
     } else {
+        expand = true;
         return true;
     }
 }
 
+static gboolean findNode (PlayListData *pld, GtkTreeModel *model, Node *node, GtkTreeIter *iter)
+{
+    bool b = true;
+    return findNodeImpl (pld, model, node, iter, b);
+}
+
 void KMPlayer::updatePlayTree (Application *app) {
     app->in_tree_update = true;
     PlayListData *pld = CONTROL(app)->playlist_data;
@@ -217,7 +227,7 @@ void KMPlayer::updatePlayTree (Application *app) {
 
     Node *node = pld->current.ptr ();
     if (!pld->show_all)
-        while (node && !node->expose ())
+        while (node && !node->role (RolePlaylist))
             node = node->parentNode ();
     if (!node) {
         // undo selection
@@ -367,7 +377,7 @@ void cb_treerow_expanded (GtkTreeView *treeview, GtkTreeIter *arg1, GtkTreePath
 static Node *findFirstLevelExposed (Node *n, int & idx) {
     if (!n)
         return n;
-    if (n->expose ()) {
+    if (n->role (RolePlaylist)) {
         if (--idx < 0)
             return n;
     } else { // not exposed node, check deeper ..
@@ -421,6 +431,9 @@ static void setInfoContent (Application *app, Node *node, bool edit_mode) {
 }
 
 static gboolean delayedUpdateTree (Application *app) {
+#ifdef DEBUG_TIMERS
+    debugLog() << "delayedUpdateTree" << endl;
+#endif
     for (PlayListData *pd = CONTROL(app)->playlist_data; pd; pd = pd->next) {
         if (pd->document &&
                 (!pd->updated_document ||
@@ -456,6 +469,9 @@ static bool had_selection_change;
 
 static gboolean cb_tapTimeout (gpointer)
 {
+#ifdef DEBUG_TIMERS
+    debugLog() << "cb_tapTimeout" << endl;
+#endif
     had_selection_change = false;
     return false;
 }
@@ -509,6 +525,9 @@ static void cb_selection_changed (GtkTreeSelection *selection, Application *app)
 
 static gboolean delayedJump (Application *app) {
     GtkTreePath *path;
+#ifdef DEBUG_TIMERS
+    debugLog() << "delayedJump" << endl;
+#endif
     PlayListData * pld = getListDataFromSelection (app, &path);
     if (pld) {
         jump (pld->current.ptr (), CONTROL(app));
@@ -955,11 +974,14 @@ void cb_playlistTitle (Application *app) {
     PlayListData *pld = getListDataFromSelection (app, &path);
     if (pld) {
         Node *node = getNode (pld, path);
-        if (node && pld->id == app->playlists_tree_id) {
-            String title = node->caption ();
-            title = getUserInput (app, "New Title", "Enter new title", title);
+        PlaylistRole *pr = node ? (PlaylistRole*)node->role(RolePlaylist): NULL;
+        if (pr && pld->id == app->playlists_tree_id) {
+            String title = getUserInput (app,
+                    "New Title", "Enter new title", pr->caption ());
             if (!title.isNull ()) {
-                node->setCaption (title);
+                pr->setCaption (title);
+                static_cast <Element *> (node)->setAttribute (
+                        StringPool::attr_title, title);
                 node->document ()->m_tree_version++;
                 updateTree (app, app->playlists_tree_id);
             }
