@@ -1,4 +1,4 @@
-/* This file is part of the KDE project
+/* This file is part of the KMPlayer project
  *
  * Copyright (C) 2004 Koos Vriezen <koos.vriezen@xs4all.nl>
  *
@@ -32,6 +32,9 @@ extern int shared_data_count;
 
 namespace KMPlayer {
 
+void *sharedDataAlloc (size_t s);
+void sharedDataFree (void *p);
+
 /**
  *  Shared data for SharedPtr and WeakPtr objects.
  **/
@@ -45,6 +48,8 @@ struct SharedData {
 #ifdef SHAREDPTR_DEBUG
     ~SharedData () { std::cerr << "SharedData::~SharedData" << " total:" << --shared_data_count << std::endl; }
 #endif
+    void *operator new (size_t);
+    void operator delete (void *);
     void addRef ();
     void addWeakRef ();
     void release ();
@@ -55,6 +60,14 @@ struct SharedData {
     T * ptr;
 };
 
+template <class T> inline void *SharedData<T>::operator new (size_t s) {
+    return sharedDataAlloc (s);
+}
+
+template <class T> inline void SharedData<T>::operator delete (void *p) {
+    sharedDataFree (p);
+}
+
 template <class T> inline void SharedData<T>::addRef () {
     use_count++;
     weak_count++;
@@ -92,8 +105,9 @@ template <class T> inline void SharedData<T>::dispose () {
 #ifdef SHAREDPTR_DEBUG
     std::cerr << "SharedData::dispose use:" << use_count << " weak:" << weak_count << std::endl;
 #endif
-    delete ptr;
-    ptr = 0;
+    T *p = ptr;
+    ptr = NULL;
+    delete p;
 }
 
 template <class T> struct WeakPtr;
