@@ -886,7 +886,7 @@ namespace KMPlayer {
         CurlGetJob (IOJobListener * rec, const String & u);
         ~CurlGetJob ();
 
-        void init (IOJob *job);
+        void init (IOJob *job, off_t pos);
         void start ();
 
         static size_t headerLine( void *p, size_t sz, size_t n, void *strm);
@@ -976,7 +976,9 @@ void icConnection (ConIcConnection *conn, ConIcConnectionEvent *ev, gpointer) {
 }
 
 static void curlChannelDestroy (gpointer) {
-    //debugLog() << "channel destoyed" << endl;
+#ifdef DEBUG_TIMERS
+    debugLog() << "curlChannelDestroy" << endl;
+#endif
 }
 
 static void updateReadWatches() {
@@ -1056,8 +1058,14 @@ static void curlPerformMulti () {
     while (msg) {
         if (CURLMSG_DONE == msg->msg) {
             IOJob *job = (IOJob *)g_tree_lookup (easy_list, msg->easy_handle);
-            if (job)
+            if (job) {
+                if (CURLE_OK != msg->data.result &&
+                        CURLE_PARTIAL_FILE != msg->data.result) {
+                    debugLog() << "curl error " << msg->data.result << endl;
+                    job->setError ();
+                }
                 delete job;
+            }
         }
         msg = curl_multi_info_read (CurlGetJob::multi, &messages);
     }
@@ -1070,6 +1078,9 @@ static void curlPerformMulti () {
 }
 
 static gboolean curlTimeOut (void *) {
+#ifdef DEBUG_TIMERS
+    debugLog() << "curlTimeOut" << endl;
+#endif
     curlPerformMulti ();
     if (g_tree_height (easy_list))
         return 1; // continue
@@ -1079,11 +1090,16 @@ static gboolean curlTimeOut (void *) {
 }
 
 static gboolean curlChannelRead (GIOChannel *src, GIOCondition c, gpointer d) {
+#ifdef DEBUG_TIMERS
+    debugLog() << "curlChannelRead" << endl;
+#endif
     curlPerformMulti ();
 }
 
 static gboolean curlChannelWrite (GIOChannel *src, GIOCondition c, gpointer d) {
-    //debugLog() << "curl connected" << endl;
+#ifdef DEBUG_TIMERS
+    debugLog() << "curl connected" << endl;
+#endif
     curlPerformMulti ();
 }
 size_t CurlGetJob::headerLine( void *ptr, size_t size, size_t nmemb, void *stream) {
@@ -1159,7 +1175,7 @@ CurlGetJob::CurlGetJob (IOJobListener * rec, const String & u)
    error_code (0), content_length (0)
 {}
 
-void CurlGetJob::init (IOJob *job) {
+void CurlGetJob::init (IOJob *job, off_t pos) {
     if (!global_init) {
         global_init = !curl_global_init (CURL_GLOBAL_ALL);
         easy_list = g_tree_new (easyCompare);
@@ -1178,6 +1194,8 @@ void CurlGetJob::init (IOJob *job) {
     curl_easy_setopt (easy, CURLOPT_WRITEDATA, job);
     curl_easy_setopt (easy, CURLOPT_HEADERFUNCTION, CurlGetJob::headerLine);
     curl_easy_setopt (easy, CURLOPT_WRITEHEADER, job);
+    if (pos)
+        curl_easy_setopt (easy, CURLOPT_RESUME_FROM_LARGE, (unsigned long long) pos);
     if (post_data.size ()) {
         curl_easy_setopt (easy, CURLOPT_POST, 1);
         curl_easy_setopt (easy, CURLOPT_POSTFIELDSIZE, post_data.size ());
@@ -1258,8 +1276,8 @@ KMPLAYER_NO_EXPORT void IOJob::setHttpPostData (const ByteArray &data) {
     d->post_data = data;
 }
 
-KMPLAYER_NO_EXPORT void IOJob::start () {
-    d->init (this);
+KMPLAYER_NO_EXPORT void IOJob::start (off_t pos) {
+    d->init (this, pos);
 }
 
 KMPLAYER_NO_EXPORT void IOJob::kill (bool q) {
@@ -1276,6 +1294,10 @@ KMPLAYER_NO_EXPORT bool IOJob::error () {
     return d->error_code;
 }
 
+KMPLAYER_NO_EXPORT void IOJob::setError () {
+    d->error_code = 1;
+}
+
 unsigned long IOJob::contentLength() const {
     return d->content_length;
 }
